==> blobbr-write-to-disk-1.0.1.tgz: package/test/index.spec.js <==
'use strict';

const packageName = require('../package.json').name;
const debug = require('debug')(packageName);
const chai = require('chai');
const dirtyChai = require('dirty-chai');
const processorGenerator = require('../src/');
const JsonSchema = require('jsonschema');
const errors = require('blobbr-pipeline-errors');
const BadConfig = errors.BadConfig;
const UnexpectedPipelineAbort = errors.UnexpectedPipelineAbort;
const fs = require('fs-extra');
const path = require('path');
const validate = JsonSchema.validate;
const expect = chai.expect;
chai.use(dirtyChai);

const outputDirectory = path.resolve('./testFiles');

const goodConfig = {
  directory: outputDirectory
};

const badConfig = {
  directory: '/this/path/does/not/exists'
};

const badConfig2 = {
  directory: path.resolve('./test/index.spec.js')
};

describe('Write to disk', () => {
  before(next => {
    debug(`creating directory ${outputDirectory}`);
    fs.mkdir(outputDirectory, next);
  });

  after(next => {
    debug(`removing directory ${outputDirectory}`);
    fs.remove(outputDirectory, next);
  });

  describe('Config', () => {
    it('Should accept good config', () => {
      processorGenerator(goodConfig);
    });
    it('Should reject a non existant directory', () => {
      try {
        processorGenerator(badConfig);
      } catch (e) {
        expect(e).to.be.instanceof(BadConfig);
        expect(e.code).to.be.equal('bc-blobbr-write-to-disk-1');
      }
    });
    it('Should reject a non directory', () => {
      try {
        processorGenerator(badConfig2);
      } catch (e) {
        expect(e).to.be.instanceof(BadConfig);
        expect(e.code).to.be.equal('bc-blobbr-write-to-disk-2');
      }
    });
  });

  describe('Writing to disk', () => {
    it('should effectively write the files on disk', next => {
      const content = new Buffer('This is a super file you should keep');
      const content2 = new Buffer('This one is less important but anyway');
      const input = {
        log() {},
        files: [{
          name: 'toto.js',
          buffer: content,
          size: content.length,
          type: 'text/plain'
        }, {
          name: 'toto2.js',
          buffer: content2,
          size: content2.length,
          type: 'text/plain'
        }]
      };
      const processor = processorGenerator(goodConfig);
      const outputPromise = processor(input);
      outputPromise
        .then(output => {
          const validation = validate(output, processor.outputSchema);
          expect(validation.valid).to.be.true();
          const files = output.output['blobbr-write-to-disk'].files;
          files.forEach((filename, index) => {
            const stat = fs.statSync(filename);
            expect(stat.isFile()).to.be.true();
            const content = fs.readFileSync(filename);
            expect(content).to.deep.equal(input.files[index].buffer);
          });
          expect(files).to.have.lengthOf(2);
          next();
        })
        .catch(next);
    });

    it('Should not work if the directory is not writable', next => {
      const fileContent = new Buffer('I wont be written on disk');
      const forbiddenConfig = {
        directory: '/root'
      };
      const processor = processorGenerator(forbiddenConfig);
      processor({
        log() {},
        files: [{
          name: 'happiste2.txt',
          buffer: fileContent,
          size: fileContent.length,
          type: 'text/plain'
        }]
      })
        .then(() => {
          next('This is not ok');
        })
        .catch(error => {
          expect(error).to.be.instanceof(UnexpectedPipelineAbort);
          next();
        })
        .catch(next);
    });
  });
});

==> blobbr-write-to-disk-2.0.0.tgz: package/test/index.spec.js <==
'use strict';

const packageName = require('../package.json').name;
const debug = require('debug')(packageName);
const chai = require('chai');
const dirtyChai = require('dirty-chai');
const processorGenerator = require('../src/');
const JsonSchema = require('jsonschema');
const errors = require('blobbr-pipeline-errors');
const BadConfig = errors.BadConfig;
const UnexpectedPipelineAbort = errors.UnexpectedPipelineAbort;
const fs = require('fs-extra');
const path = require('path');
const validate = JsonSchema.validate;
const expect = chai.expect;
chai.use(dirtyChai);

const outputDirectory = path.resolve('./testFiles');

const goodConfig = {
  directory: outputDirectory
};

const badConfig = {
  directory: '/this/path/does/not/exists'
};

const badConfig2 = {
  directory: path.resolve('./test/index.spec.js')
};

describe('Write to disk', () => {
  before(next => {
    debug(`creating directory ${outputDirectory}`);
    fs.mkdir(outputDirectory, next);
  });

  after(next => {
    debug(`removing directory ${outputDirectory}`);
    fs.remove(outputDirectory, next);
  });

  describe('Config', () => {
    it('Should accept good config', () => {
      processorGenerator(goodConfig);
    });
    it('Should reject a non existant directory', () => {
      try {
        processorGenerator(badConfig);
      } catch (e) {
        expect(e).to.be.instanceof(BadConfig);
        expect(e.code).to.be.equal('bc-blobbr-write-to-disk-1');
      }
    });
    it('Should reject a non directory', () => {
      try {
        processorGenerator(badConfig2);
      } catch (e) {
        expect(e).to.be.instanceof(BadConfig);
        expect(e.code).to.be.equal('bc-blobbr-write-to-disk-2');
      }
    });
  });

  describe('Writing to disk', () => {
    it('should effectively write the files on disk', next => {
      const content = new Buffer('This is a super file you should keep');
      const content2 = new Buffer('This one is less important but anyway');
      const input = {
        log() {},
        files: [{
          name: 'toto.js',
          buffer: content,
          size: content.length,
          type: 'text/plain'
        }, {
          name: 'toto2.js',
          buffer: content2,
          size: content2.length,
          type: 'text/plain'
        }]
      };
      const processor = processorGenerator(goodConfig);
      const outputPromise = processor(input);
      outputPromise
        .then(output => {
          const validation = validate(output, processor.outputSchema);
          expect(validation.valid).to.be.true();
          const files = output.output['blobbr-write-to-disk'].files;
          files.forEach((filename, index) => {
            const p = path.resolve(outputDirectory, filename);
            const stat = fs.statSync(p);
            expect(stat.isFile()).to.be.true();
            const content = fs.readFileSync(p);
            expect(content).to.deep.equal(input.files[index].buffer);
          });
          expect(files).to.have.lengthOf(2);
          next();
        })
        .catch(next);
    });

    it('Should not work if the directory is not writable', next => {
      const fileContent = new Buffer('I wont be written on disk');
      const forbiddenConfig = {
        directory: '/root'
      };
      const processor = processorGenerator(forbiddenConfig);
      processor({
        log() {},
        files: [{
          name: 'happiste2.txt',
          buffer: fileContent,
          size: fileContent.length,
          type: 'text/plain'
        }]
      })
        .then(() => {
          next('This is not ok');
        })
        .catch(error => {
          expect(error).to.be.instanceof(UnexpectedPipelineAbort);
          next();
        })
        .catch(next);
    });
  });
});
